var IConnection_8h =
[
    [ "sdbus::IConnection", "classsdbus_1_1IConnection.html", "classsdbus_1_1IConnection" ],
    [ "sdbus::IConnection::PollData", "structsdbus_1_1IConnection_1_1PollData.html", "structsdbus_1_1IConnection_1_1PollData" ],
    [ "createBusConnection", "IConnection_8h.html#a75d10a9959cba1f12beced684cc3005e", null ],
    [ "createBusConnection", "IConnection_8h.html#a265fa30ac626c67ee87fc6b6e7da38de", null ],
    [ "createBusConnection", "IConnection_8h.html#a4ddb605a6f4040fa95dbaf48c4e83f4b", null ],
    [ "createDirectBusConnection", "IConnection_8h.html#aa48c1746501c163547344b2a9f57673c", null ],
    [ "createDirectBusConnection", "IConnection_8h.html#a5c0a6e52e132a1d8984cb64e06906162", null ],
    [ "createRemoteSystemBusConnection", "IConnection_8h.html#a803551c47da11b5d137c2b7132453828", null ],
    [ "createServerBus", "IConnection_8h.html#ac1b366259d5cb3b29de728b5f3d960a8", null ],
    [ "createSessionBusConnection", "IConnection_8h.html#a0b7b34085806849eca7151684834734a", null ],
    [ "createSessionBusConnection", "IConnection_8h.html#ad7281cd42c0cbeb28bad60bfebad4623", null ],
    [ "createSessionBusConnectionWithAddress", "IConnection_8h.html#a2bb69db85ee48bdaa3419b09a254ed7a", null ],
    [ "createSystemBusConnection", "IConnection_8h.html#a0f668f4cca77b73dfd425a2123b596cf", null ],
    [ "createSystemBusConnection", "IConnection_8h.html#a6dc6c5063588043c20ffe4806b94307b", null ]
];